@@ -27,7 +27,7 @@ pub struct Contest {
 }
 
 #[derive(Debug, Serialize, Deserialize, Clone)]
-struct SerialziedContest {
+struct SerializedContest {
     template: String,
     problems: Vec<String>,
     problem_count: Option<u32>,
@@ -62,7 +62,7 @@ fn parse_contest_yaml<P: AsRef<Path>, Q: AsRef<Path>>(
 ) -> ContestFetchResult {
     let problem_dir: &Path = problem_dir.as_ref();
     let template_dir: &Path = template_dir.as_ref();
-    match serde_yaml::from_str::<SerialziedContest>(yaml) {
+    match serde_yaml::from_str::<SerializedContest>(yaml) {
         Ok(serialized_contest) => {
             match fetch_template_config(&serialized_contest.template, template_dir) {
                 Ok(template) => {
