@@ -168,7 +168,7 @@ impl Problem {
     ///
     /// If `filters` is empty, then every problem will pass the filter.
 
-    pub fn filter(self, filters: &Vec<FilterAction>) -> Option<Problem> {
+    pub fn filter(self, filters: &[FilterAction]) -> Option<Problem> {
         for filter_action in filters {
             match filter_action {
                 Positive(filter) => {
