@@ -14,10 +14,7 @@ use std::path::Path;
 /// You should always have `originator` be `true` when calling the function yourself,
 /// `false` is for recursive calls.
 
-pub(crate) fn copy_dir_ignore_dots<P, Q>(from: P, to: Q) -> std::io::Result<()>
-where
-    P: AsRef<Path>,
-    Q: AsRef<Path>,
+pub(crate) fn copy_dir_ignore_dots<P: AsRef<Path>, Q: AsRef<Path>>(from: P, to: Q) -> std::io::Result<()>
 {
     let from = from.as_ref();
     let to = to.as_ref();
@@ -29,10 +26,9 @@ where
             );
             return Err(std::io::Error::new(std::io::ErrorKind::Other, err.as_str()));
         }
-        match std::fs::create_dir(&to) {
-            Err(e) => return Err(e),
-            Ok(_) => {}
-        }
+        if let Err(e) = std::fs::create_dir(&to) {
+            return Err(e);
+        };
     }
     for entry in fs::read_dir(from)? {
         let entry = entry?;
@@ -42,7 +38,7 @@ where
             let destination = &to.join(file_name);
             if path.is_file() || path.is_symlink() {
                 fs::copy(path, destination)
-                    .expect(&format!("Failed to copy {:?} to {:?}", path, destination));
+                    .unwrap_or_else(|_| panic!("Failed to copy {:?} to {:?}", path, destination));
             } else {
                 if !destination.is_dir() {
                     if destination.exists() {
@@ -52,10 +48,9 @@ where
                     );
                         return Err(std::io::Error::new(std::io::ErrorKind::Other, err.as_str()));
                     }
-                    match std::fs::create_dir(destination) {
-                        Err(e) => return Err(e),
-                        Ok(_) => {}
-                    }
+                    if let Err(e) = std::fs::create_dir(destination) {
+                        return Err(e);
+                    };
                 }
                 copy_dir_ignore_dots(path, destination)?
             }
